@@ -1,6 +1,8 @@
 import commonjs from '@rollup/plugin-commonjs';
 import { nodeResolve } from '@rollup/plugin-node-resolve';
-const pkg = require(process.env.PWD+'/package.json');
+import { builtinModules } from 'module';
+import fs from 'fs';
+const pkg = JSON.parse(fs.readFileSync(process.env.PWD+'/package.json'));
 if(!pkg.dependencies) pkg.dependencies={};
 const file = process.env.DEST_FILE ? process.env.DEST_FILE : pkg.exports && pkg.exports.require ? pkg.exports.require : 'index.cjs';
 
@@ -10,17 +12,15 @@ const config = {
 		format: 'cjs',
 		file: file,
 		preferConst: true,
-		interop: false,
+		interop: 'auto',
 		freeze: false,
 		strict: false
 	}],
-	external: [
-		...require('module').builtinModules,
-	],
+	external: builtinModules,
 	plugins: [
         commonjs(),
         nodeResolve({
-            moduleDirectories: ['node_modules', ...process.config.variables.node_relative_path.split(':').map((str) => process.config.variables.node_prefix + '/' + str)],
+            modulePaths: ['node_modules', ...process.config.variables.node_relative_path.split(':').map((str) => process.config.variables.node_prefix + '/' + str)],
         }),
 	]
 }
